==> kphotoalbum-5.3.tar.xz: kphotoalbum-5.3/BackgroundTaskManager/JobViewer.h <==
/* Copyright 2012-2016 Jesper K. Pedersen <blackie@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BACKGROUNDTASKS_JOBVIEWER_H
#define BACKGROUNDTASKS_JOBVIEWER_H

#include <QDialog>

class QTreeView;
class QPushButton;

namespace BackgroundTaskManager {

class JobModel;

class JobViewer : public QDialog
{
    Q_OBJECT

public:
    explicit JobViewer(QWidget *parent = nullptr);
    void setVisible(bool) override;

private slots:
    void togglePause();

private:
    void updatePauseButton();
    JobModel* m_model;
    QTreeView* m_treeView;
    QPushButton* m_pauseButton;
};

} // namespace BackgroundTaskManager

#endif // BACKGROUNDTASKS_JOBVIEWER_H

// vi:expandtab:tabstop=4 shiftwidth=4:

==> kphotoalbum_5.6.1.orig.tar.xz: kphotoalbum-5.6.1/BackgroundTaskManager/JobViewer.h <==
/* Copyright 2012-2016 Jesper K. Pedersen <blackie@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BACKGROUNDTASKS_JOBVIEWER_H
#define BACKGROUNDTASKS_JOBVIEWER_H

#include <QDialog>

class QTreeView;
class QPushButton;

namespace BackgroundTaskManager
{

class JobModel;

class JobViewer : public QDialog
{
    Q_OBJECT

public:
    explicit JobViewer(QWidget *parent = nullptr);
    void setVisible(bool) override;

private slots:
    void togglePause();

private:
    void updatePauseButton();
    JobModel *m_model;
    QTreeView *m_treeView;
    QPushButton *m_pauseButton;
};

} // namespace BackgroundTaskManager

#endif // BACKGROUNDTASKS_JOBVIEWER_H

// vi:expandtab:tabstop=4 shiftwidth=4:
